@@ -913,6 +913,7 @@ class Database:
             name_list.remove('hk_full_market')
 
         return name_list
+
     def get_all_hk_stock_plate_name(self):
 
         link_url = 'http://www.hkfdb.net/data_api?'
@@ -935,7 +936,14 @@ class Database:
         link_str = link_url + '&' + token_str + '&' + database_str
         
         response = requests.get(link_str)
-        json1 = json.loads(response.content).replace("'", "\"").replace('nan','NaN')
+        r_content = response.content
+        json1 = json.loads(r_content)
+        json1 = json.loads(r_content).replace("'", "\"")
+        json1 = json1.replace('nan','NaN')
+        json1 = json1.replace('INT\"L','INTL')
+        json1 = json1.replace('L\"OCCITANE','LOCCITANE')
+
+
         result = json.loads(json1)
 
         df = pd.DataFrame(result)
@@ -950,7 +958,7 @@ class Database:
         
         df['share_issued'] = df['share_issued'].astype(int)
         df['market_capital'] = df['market_capital'].astype(int)
-
+        df = df[['stock_name','code','price','PE','EPS','dividend','volume','turnover','share_issued','lot_size','market_capital','ipo_date','year_end_date']]
         return df
 
     def get_hk_ipo_hist(self):
